"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DeleteButton = void 0;

var _core = require("@material-ui/core");

var _react = _interopRequireWildcard(require("react"));

var _hooks = require("../../hooks");

var _confirmationDialog = require("../confirmation-dialog");

/**
 * Represents a delete button with confirmation dialog
 */
const DeleteButton = props => {
  const [isDialogOpen, setIsDialogOpen] = (0, _react.useState)(false);
  const api = (0, _hooks.useDocumentViewerApi)();
  const {
    documentData
  } = (0, _hooks.useDocumentData)();
  const localization = (0, _hooks.useLocalization)();

  const handleClick = () => {
    setIsDialogOpen(true);
  };

  const handleDialogClose = isCanceled => {
    if (!isCanceled) {
      api.commentActions.deletePreviewComment({
        document: documentData,
        commentId: props.comment.id,
        abortController: new AbortController()
      });
    }

    setIsDialogOpen(false);
  };

  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_core.Button, {
    color: "primary",
    size: "small",
    onClick: handleClick
  }, localization.delete), /*#__PURE__*/_react.default.createElement(_confirmationDialog.ConfirmationDialog, {
    dialogTitle: localization.deleteCommentDialogTitle,
    cancelButtonText: localization.cancelButton,
    okButtonText: localization.okButton,
    isOpen: isDialogOpen,
    onClose: handleDialogClose
  }, localization.deleteCommentDialogBody));
};

exports.DeleteButton = DeleteButton;
//# sourceMappingURL=delete-comment-button.js.map