"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DocumentViewerLayout = exports.PAGE_CONTAINER_ID = exports.PAGE_NAME = exports.PAGE_PADDING = exports.THUMBNAIL_CONTAINER_ID = exports.THUMBNAIL_NAME = exports.THUMBNAIL_PADDING = void 0;

var _core = require("@material-ui/core");

var _react = _interopRequireWildcard(require("react"));

var _comments = require("../context/comments");

var _hooks = require("../hooks");

var _comment = require("./comment");

var _ = require("./");

const THUMBNAIL_PADDING = 16;
exports.THUMBNAIL_PADDING = THUMBNAIL_PADDING;
const THUMBNAIL_NAME = 'Thumbnail';
exports.THUMBNAIL_NAME = THUMBNAIL_NAME;
const THUMBNAIL_CONTAINER_ID = 'sn-document-viewer-thumbnails';
exports.THUMBNAIL_CONTAINER_ID = THUMBNAIL_CONTAINER_ID;
const PAGE_PADDING = 8;
exports.PAGE_PADDING = PAGE_PADDING;
const PAGE_NAME = 'Page';
exports.PAGE_NAME = PAGE_NAME;
const PAGE_CONTAINER_ID = 'sn-document-viewer-pages';
exports.PAGE_CONTAINER_ID = PAGE_CONTAINER_ID;
const useStyles = (0, _core.makeStyles)(() => {
  return (0, _core.createStyles)({
    mainWrapper: {
      width: '100%',
      height: '100%',
      display: 'flex',
      flexDirection: 'column',
      flexGrow: 1
    },
    layout: {
      display: 'flex',
      flexGrow: 1,
      width: '100%',
      overflow: 'hidden',
      zIndex: 0,
      position: 'relative'
    },
    commentContainer: {
      display: 'flex',
      flexFlow: 'column',
      padding: '15px',
      justifyContent: 'space-between',
      alignItems: 'center',
      overflow: 'auto'
    }
  });
});

const DocumentViewerLayout = () => {
  const classes = useStyles();
  const viewerState = (0, _hooks.useViewerState)();
  const localization = (0, _hooks.useLocalization)();
  const viewerSettings = (0, _hooks.useViewerSettings)();
  const scrollToImage = (0, _react.useCallback)(({
    containerId,
    index,
    itemName,
    padding,
    smoothScroll
  }) => {
    const container = document.getElementById(containerId);
    const item = document.querySelector(`.${itemName}`);

    if (container && container.scrollTo && item) {
      container.scrollTo({
        top: (item.clientHeight + padding * 4) * (index - 1),
        behavior: smoothScroll ? 'smooth' : 'auto'
      });
    }
  }, []);
  const scrollTo = (0, _react.useCallback)((index, smoothScroll = true) => {
    scrollToImage({
      containerId: PAGE_CONTAINER_ID,
      itemName: PAGE_NAME,
      padding: PAGE_PADDING,
      index,
      smoothScroll
    });
    scrollToImage({
      containerId: THUMBNAIL_CONTAINER_ID,
      itemName: THUMBNAIL_NAME,
      padding: THUMBNAIL_PADDING,
      index,
      smoothScroll
    });
  }, [scrollToImage]);
  (0, _react.useEffect)(() => {
    const observer = viewerState.pageToGo.subscribe(({
      page
    }) => {
      scrollTo(page);
    });
    return () => observer.dispose();
  }, [scrollTo, viewerState.pageToGo]);
  return /*#__PURE__*/_react.default.createElement("div", {
    className: classes.mainWrapper
  }, viewerSettings.renderAppBar(), /*#__PURE__*/_react.default.createElement("div", {
    className: classes.layout
  }, /*#__PURE__*/_react.default.createElement(_core.Drawer, {
    variant: 'persistent',
    open: viewerState.showThumbnails,
    anchor: "left",
    SlideProps: viewerSettings.drawerSlideProps,
    PaperProps: {
      style: {
        position: 'relative',
        width: viewerState.showThumbnails ? '200px' : 0,
        height: '100%',
        overflow: 'hidden'
      }
    }
  }, viewerState.showThumbnails && /*#__PURE__*/_react.default.createElement(_.Thumbnails, {
    onPageClick: index => scrollTo(index)
  })), /*#__PURE__*/_react.default.createElement(_.PageList, {
    onPageClick: index => scrollTo(index)
  }), /*#__PURE__*/_react.default.createElement(_core.Drawer, {
    variant: 'persistent',
    open: viewerState.showComments,
    anchor: "right",
    SlideProps: viewerSettings.drawerSlideProps,
    PaperProps: {
      style: {
        position: 'relative',
        width: viewerState.showComments ? '340px' : 0,
        height: '100%',
        overflow: 'hidden'
      }
    }
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: classes.commentContainer
  }, /*#__PURE__*/_react.default.createElement(_core.Typography, {
    variant: "h4"
  }, localization.commentSideBarTitle), /*#__PURE__*/_react.default.createElement(_comment.CreateComment, null), /*#__PURE__*/_react.default.createElement(_comments.CommentsContext.Consumer, null, commentsContext => commentsContext.comments.map(comment => /*#__PURE__*/_react.default.createElement(_comment.Comment, {
    key: comment.id,
    comment: comment
  })))))));
};

exports.DocumentViewerLayout = DocumentViewerLayout;
//# sourceMappingURL=document-viewer-layout.js.map