"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DocumentTitlePager = void 0;

var _core = require("@material-ui/core");

var _react = _interopRequireWildcard(require("react"));

var _hooks = require("../../hooks");

const useStyles = (0, _core.makeStyles)(() => {
  return (0, _core.createStyles)({
    typography: {
      cursor: 'pointer',
      display: 'flex',
      alignItems: 'center',
      overflow: 'hidden',
      margin: '0 2.5em'
    },
    nameWrapper: {
      whiteSpace: 'nowrap',
      overflow: 'hidden',
      textOverflow: 'ellipsis'
    },
    textField: {
      flexShrink: 0
    },
    notFocusedText: {
      flexShrink: 0
    }
  });
});

/**
 * Document widget component for paging
 */
const DocumentTitlePager = props => {
  const classes = useStyles(props);
  const {
    documentData
  } = (0, _hooks.useDocumentData)();
  const viewerState = (0, _hooks.useViewerState)();
  const localization = (0, _hooks.useLocalization)();
  const [isFocused, setIsFocused] = (0, _react.useState)(false);
  const [currentValue, setCurrentValue] = (0, _react.useState)(viewerState.activePage);

  const gotoPage = page => {
    let pageInt = typeof page === 'string' ? parseInt(page, 10) : page;

    if (!isNaN(pageInt)) {
      pageInt = Math.max(pageInt, 1);
      pageInt = Math.min(pageInt, documentData.pageCount);
      viewerState.pageToGo.setValue({
        page: pageInt
      });
    }
  };

  return /*#__PURE__*/_react.default.createElement(_core.ClickAwayListener, {
    onClickAway: () => setIsFocused(false)
  }, /*#__PURE__*/_react.default.createElement(_core.Typography, {
    onClick: () => setIsFocused(true),
    variant: "h6",
    color: "inherit",
    title: documentData.documentName,
    className: classes.typography
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: classes.nameWrapper
  }, documentData.documentName, "\xA0"), isFocused ? /*#__PURE__*/_react.default.createElement("form", {
    onSubmit: ev => {
      gotoPage(currentValue);
      ev.preventDefault();
    }
  }, /*#__PURE__*/_react.default.createElement(_core.TextField, {
    className: classes.textField,
    title: localization.gotoPage,
    onChange: ev => setCurrentValue(ev.currentTarget.value),
    onBlur: () => gotoPage(currentValue),
    defaultValue: viewerState.activePage,
    type: "number",
    required: true,
    InputLabelProps: {
      shrink: true
    },
    inputProps: {
      min: 1,
      max: documentData.pageCount,
      style: {
        textAlign: 'center'
      }
    },
    margin: "dense"
  })) : /*#__PURE__*/_react.default.createElement("div", {
    className: classes.notFocusedText
  }, viewerState.activePage, " / ", documentData.pageCount)));
};

exports.DocumentTitlePager = DocumentTitlePager;
//# sourceMappingURL=document-title-pager.js.map