"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PageList = void 0;

var _clientUtils = require("@sensenet/client-utils");

var _core = require("@material-ui/core");

var _react = _interopRequireWildcard(require("react"));

var _hooks = require("../hooks");

var _services = require("../services");

var _ = require("./");

const useStyles = (0, _core.makeStyles)(() => {
  return (0, _core.createStyles)({
    grid: {
      flexGrow: 1,
      flexShrink: 1,
      overflow: 'auto'
    },
    pagesWrapper: {
      display: 'flex',
      flexDirection: 'column',
      justifyContent: 'center',
      alignItems: 'center'
    }
  });
});
/**
 * Defines the own properties for the PageList component
 */

const PageList = props => {
  const [paddingTop, setPaddingTop] = (0, _react.useState)(0);
  const [paddingBottom, setPaddingBottom] = (0, _react.useState)(0);
  const [visiblePages, setVisiblePages] = (0, _react.useState)([]);
  const [scrollState, setScrollState] = (0, _react.useState)(0);
  const viewportElement = (0, _react.useRef)();
  const viewerState = (0, _hooks.useViewerState)();
  const [resizeToken, setResizeToken] = (0, _react.useState)(0);
  const [viewport, setViewport] = (0, _react.useState)({
    width: 0,
    height: 0
  });
  const pages = (0, _hooks.usePreviewImages)();
  const classes = useStyles();
  const requestResize = (0, _react.useCallback)((0, _clientUtils.debounce)(() => {
    setResizeToken(Math.random());
  }, 300), []);
  const onScroll = (0, _react.useCallback)(() => {
    requestResize();
    setScrollState(viewportElement.current && viewportElement.current.scrollTop || 0);
  }, [requestResize]);
  (0, _react.useEffect)(() => {
    const currentViewport = viewportElement.current;

    if (currentViewport) {
      currentViewport.addEventListener('scroll', onScroll);
    }

    return () => currentViewport && currentViewport.removeEventListener('scroll', onScroll);
  }, [onScroll, viewportElement]);
  (0, _react.useEffect)(() => {
    window.addEventListener('resize', requestResize);
    return () => window.removeEventListener('resize', requestResize);
  }, [requestResize]);
  (0, _react.useEffect)(() => {
    if (viewportElement && viewportElement.current) {
      const newHeight = viewportElement.current.clientHeight - _.PAGE_PADDING * 2;
      const newWidth = viewportElement.current.clientWidth - _.PAGE_PADDING * 2;
      setViewport({
        height: newHeight >= 0 ? newHeight : 0,
        width: newWidth >= 0 ? newWidth : 0
      });
    }
  }, [resizeToken, viewportElement]);
  (0, _react.useEffect)(() => {
    if (!pages.imageData.length) {
      return;
    }

    let defaultWidth;
    let defaultHeight;

    const _visiblePages = pages.imageData.map(p => {
      var _viewerState$rotation, _viewerState$rotation2;

      if (p && !defaultWidth || !defaultHeight) {
        ;
        [defaultWidth, defaultHeight] = [p.Width, p.Height];
      }

      if (!p.Width || !p.Height) {
        ;
        [p.Width, p.Height] = [defaultWidth, defaultHeight];
      }

      const relativeSize = _services.ImageUtil.getImageSize({
        width: viewport.width,
        height: viewport.height
      }, {
        width: p.Width,
        height: p.Height,
        rotation: ((_viewerState$rotation = viewerState.rotation) === null || _viewerState$rotation === void 0 ? void 0 : (_viewerState$rotation2 = _viewerState$rotation.find(rotation => rotation.pageNum === p.Index)) === null || _viewerState$rotation2 === void 0 ? void 0 : _viewerState$rotation2.degree) || 0
      }, viewerState.zoomLevel);

      return { ...p,
        Width: relativeSize.width,
        Height: relativeSize.height
      };
    });

    let _paddingTop = 0;
    let _pagesToSkip = 0;

    while (_visiblePages[_pagesToSkip] && _paddingTop + _visiblePages[_pagesToSkip].Height < scrollState) {
      _paddingTop += _visiblePages[_pagesToSkip].Height + _.PAGE_PADDING * 2;
      _pagesToSkip++;
    }

    let _pagesToTake = 1;
    let _pagesHeight = 0;

    while (_visiblePages[_pagesToSkip + _pagesToTake] && _pagesHeight < viewport.height) {
      _pagesHeight += _visiblePages[_pagesToSkip + _pagesToTake].Height + _.PAGE_PADDING * 2;
      _pagesToTake++;
    }

    let _paddingBottom = 0;

    for (let i = _pagesToSkip + _pagesToTake - 1; i < _visiblePages.length - 1; i++) {
      _paddingBottom += _visiblePages[i].Height + _.PAGE_PADDING * 2;
    }

    setPaddingTop(_paddingTop);
    setPaddingBottom(_paddingBottom + _visiblePages[0].Height / 4);

    const newVisiblePages = _visiblePages.slice(_pagesToSkip, _pagesToSkip + _pagesToTake);

    setVisiblePages(newVisiblePages);

    if (newVisiblePages.length > 0) {
      let newActivePage;

      if (newVisiblePages.length === 1) {
        newActivePage = newVisiblePages[0].Index;
      } else {
        newActivePage = scrollState - _paddingTop >= 0 && scrollState - _paddingTop > newVisiblePages[0].Height / 2 ? newVisiblePages[1].Index : newVisiblePages[0].Index;
      }

      if (viewerState.activePage !== newActivePage) {
        viewerState.updateState({
          activePage: newActivePage
        });
      }
    }
  }, [pages.imageData, scrollState, viewerState, viewport.height, viewport.width]);
  return /*#__PURE__*/_react.default.createElement(_core.Grid, {
    item: true,
    className: classes.grid,
    id: _.PAGE_CONTAINER_ID,
    innerRef: viewportElement
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: classes.pagesWrapper,
    style: {
      paddingTop: paddingTop || 0,
      paddingBottom: paddingBottom || 0
    }
  }, visiblePages.map(page => /*#__PURE__*/_react.default.createElement(_.Page, {
    key: page.Index,
    page: page,
    viewportWidth: viewport.width,
    viewportHeight: viewport.height,
    onClick: () => props.onPageClick(page.Index)
  }))));
};

exports.PageList = PageList;
//# sourceMappingURL=page-list.js.map