"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ShapeHighlight = void 0;

var _core = require("@material-ui/core");

var _yellow = _interopRequireDefault(require("@material-ui/core/colors/yellow.js"));

var _icons = require("@material-ui/icons");

var _react = _interopRequireWildcard(require("react"));

var _ = require("../..");

var _hooks = require("../../hooks");

const useStyles = (0, _core.makeStyles)(theme => (0, _core.createStyles)({
  root: {
    top: ({
      dimensions
    }) => dimensions.top,
    left: ({
      dimensions
    }) => dimensions.left,
    width: ({
      dimensions
    }) => dimensions.width,
    height: ({
      dimensions
    }) => dimensions.height,
    position: 'absolute',
    resize: ({
      permissions,
      rotationDegree
    }) => permissions.canEdit && rotationDegree === 0 ? 'both' : 'none',
    overflow: 'auto',
    backgroundColor: _yellow.default[600],
    opacity: 0.5
  },
  button: {
    backgroundColor: theme.palette.error.light
  }
}));
/**
 * Return a styled highlight component
 * @param shape Shape attributes
 * @param permissions Permissions of the current user
 * @param dimensions Shape dimensions
 * @param zoomRatio Zoom ratio
 * @param onDragStart Function triggered on drag event
 * @param onResized Function triggered on resized event
 * @param removeShape Function triggered on delete
 * @returns styled highlight component
 */

const ShapeHighlight = props => {
  const permissions = (0, _hooks.useDocumentPermissions)();
  const classes = useStyles({ ...props,
    permissions
  });
  const localization = (0, _.useLocalization)();
  const [anchorEl, setAnchorEl] = (0, _react.useState)(null);
  const open = Boolean(anchorEl);
  const id = open ? 'highlight-delete' : undefined;

  const onRightClick = event => {
    event.preventDefault();
    setAnchorEl(anchorEl ? null : event.currentTarget);
  };

  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("div", {
    className: classes.root,
    tabIndex: 0,
    draggable: permissions.canEdit,
    onDragStart: props.onDragStart,
    onMouseUp: props.onResized,
    onContextMenu: onRightClick
  }), /*#__PURE__*/_react.default.createElement(_core.Popper, {
    id: id,
    open: open,
    anchorEl: anchorEl,
    placement: "right-start"
  }, /*#__PURE__*/_react.default.createElement(_core.ClickAwayListener, {
    onClickAway: () => setAnchorEl(null)
  }, /*#__PURE__*/_react.default.createElement(_core.Button, {
    variant: "contained",
    className: classes.button,
    onMouseUp: () => props.removeShape('highlights', props.shape.guid),
    startIcon: /*#__PURE__*/_react.default.createElement(_icons.Delete, {
      scale: props.zoomRatio
    })
  }, localization.delete))));
};

exports.ShapeHighlight = ShapeHighlight;
//# sourceMappingURL=shape-highlight.js.map