"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ShapesWidget = void 0;

var _core = require("@material-ui/core");

var _react = _interopRequireWildcard(require("react"));

var _hooks = require("../../hooks");

var _services = require("../../services");

var _shapes = require("../shapes");

var _commentMarker = require("./comment-marker");

const useStyles = (0, _core.makeStyles)(() => {
  return (0, _core.createStyles)({
    shapesContainer: {
      position: 'absolute',
      top: 0,
      left: 0,
      width: '100%',
      height: '100%',
      zIndex: 1
    }
  });
});
/**
 * Defined the component's own properties
 */

/**
 * Page widget component for displaying shapes on a page
 */
const ShapesWidget = props => {
  var _viewerState$rotation, _viewerState$rotation2, _commentState$draft, _props$page;

  const classes = useStyles();
  const permissions = (0, _hooks.useDocumentPermissions)();
  const viewerState = (0, _hooks.useViewerState)();
  const {
    documentData,
    updateDocumentData
  } = (0, _hooks.useDocumentData)();
  const comments = (0, _hooks.useComments)();
  const commentState = (0, _hooks.useCommentState)();
  const zoomRatio = props.imageRotation === 90 || props.imageRotation === 270 ? props.zoomRatioLying : props.zoomRatioStanding;
  const rotationDegree = ((_viewerState$rotation = viewerState.rotation) === null || _viewerState$rotation === void 0 ? void 0 : (_viewerState$rotation2 = _viewerState$rotation.find(rotation => rotation.pageNum === props.page.Index)) === null || _viewerState$rotation2 === void 0 ? void 0 : _viewerState$rotation2.degree) || 0;
  const visibleShapes = {
    redactions: (0, _services.applyShapeRotations)(documentData.shapes.redactions.filter(r => r.imageIndex === props.page.Index), rotationDegree, props.page),
    highlights: (0, _services.applyShapeRotations)(documentData.shapes.highlights.filter(r => r.imageIndex === props.page.Index), rotationDegree, props.page),
    annotations: (0, _services.applyShapeRotations)(documentData.shapes.annotations.filter(r => r.imageIndex === props.page.Index), rotationDegree, props.page)
  };
  const visibleComments = [...comments.comments.filter(comment => comment.page === props.page.Index), ...(props.page.Index !== undefined && ((_commentState$draft = commentState.draft) === null || _commentState$draft === void 0 ? void 0 : _commentState$draft.page) === ((_props$page = props.page) === null || _props$page === void 0 ? void 0 : _props$page.Index) ? [commentState.draft] : [])];
  const removeShape = (0, _react.useCallback)((shapeType, guid) => {
    ;
    documentData.shapes[shapeType] = documentData.shapes[shapeType].filter(s => s.guid !== guid);
    updateDocumentData(documentData);
    viewerState.updateState({
      hasChanges: true
    });
  }, [documentData, updateDocumentData, viewerState]);
  const updateShapeData = (0, _react.useCallback)((shapeType, guid, shapeChange) => {
    ;
    documentData.shapes[shapeType] = documentData.shapes[shapeType].map(s => {
      if (s.guid === guid) {
        return { ...s,
          ...shapeChange
        };
      }

      return s;
    });
    viewerState.updateState({
      hasChanges: true
    });
    updateDocumentData(documentData);
  }, [documentData, updateDocumentData, viewerState]);
  const onDrop = (0, _react.useCallback)(ev => {
    if (permissions.canEdit) {
      ev.preventDefault();
      const shapeData = JSON.parse(ev.dataTransfer.getData('shape'));
      const boundingBox = ev.currentTarget.getBoundingClientRect();
      updateShapeData(shapeData.type, shapeData.shape.guid, { ...shapeData.shape,
        imageIndex: props.page.Index,
        x: (ev.clientX - boundingBox.left - shapeData.offset.width) * (1 / zoomRatio),
        y: (ev.clientY - boundingBox.top - shapeData.offset.height) * (1 / zoomRatio)
      });
    }
  }, [permissions.canEdit, props.page.Index, updateShapeData, zoomRatio]);
  return /*#__PURE__*/_react.default.createElement("div", {
    className: classes.shapesContainer,
    onDrop: onDrop,
    onDragOver: ev => ev.preventDefault()
  }, viewerState.showComments && visibleComments.length > 0 && visibleComments.map(marker => {
    var _viewerState$rotation3, _viewerState$rotation4;

    return /*#__PURE__*/_react.default.createElement(_commentMarker.CommentMarker, {
      isSelected: marker.id === commentState.activeCommentId,
      zoomRatio: zoomRatio,
      marker: marker,
      key: marker.id,
      rotation: _services.ImageUtil.normalizeDegrees(((_viewerState$rotation3 = viewerState.rotation) === null || _viewerState$rotation3 === void 0 ? void 0 : (_viewerState$rotation4 = _viewerState$rotation3.find(rotation => rotation.pageNum === props.page.Index)) === null || _viewerState$rotation4 === void 0 ? void 0 : _viewerState$rotation4.degree) || 0)
    });
  }), /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, permissions.canHideRedaction && viewerState.showRedaction && visibleShapes.redactions.map((redaction, index) => {
    return /*#__PURE__*/_react.default.createElement(_shapes.ShapeSkeleton, {
      key: index,
      shape: redaction,
      shapeType: "redactions",
      zoomRatio: zoomRatio,
      updateShapeData: updateShapeData,
      removeShape: removeShape,
      rotationDegree: rotationDegree
    });
  }), viewerState.showShapes && visibleShapes.annotations.map((annotation, index) => {
    return /*#__PURE__*/_react.default.createElement(_shapes.ShapeSkeleton, {
      key: index,
      shape: annotation,
      shapeType: "annotations",
      zoomRatio: zoomRatio,
      updateShapeData: updateShapeData,
      removeShape: removeShape,
      rotationDegree: rotationDegree
    });
  }), viewerState.showShapes && visibleShapes.highlights.map((highlight, index) => {
    return /*#__PURE__*/_react.default.createElement(_shapes.ShapeSkeleton, {
      key: index,
      shape: highlight,
      shapeType: "highlights",
      zoomRatio: zoomRatio,
      updateShapeData: updateShapeData,
      removeShape: removeShape,
      rotationDegree: rotationDegree
    });
  })));
};

exports.ShapesWidget = ShapesWidget;
//# sourceMappingURL=shapes.js.map