"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CommentsContextProvider = exports.CommentsContext = exports.defaultCommentsContext = void 0;

var _clientUtils = require("@sensenet/client-utils");

var _react = _interopRequireWildcard(require("react"));

var _hooks = require("../hooks");

const defaultCommentsContext = {
  comments: [],
  addPreviewComment: async () => undefined,
  deletePreviewComment: async () => undefined,
  getPreviewComments: async () => undefined
};
exports.defaultCommentsContext = defaultCommentsContext;
const CommentsContext = /*#__PURE__*/(0, _react.createContext)(defaultCommentsContext);
exports.CommentsContext = CommentsContext;

const CommentsContextProvider = props => {
  const api = (0, _hooks.useDocumentViewerApi)();
  const {
    documentData
  } = (0, _hooks.useDocumentData)();
  const viewerState = (0, _hooks.useViewerState)();
  const [comments, setComments] = (0, _react.useState)([]);
  (0, _react.useEffect)(() => {
    const abortController = new AbortController();

    (async () => {
      if (viewerState.showComments) {
        const result = await api.commentActions.getPreviewComments({
          document: documentData,
          page: viewerState.activePage,
          abortController
        });
        setComments(result);
      }
    })();

    return () => abortController.abort();
  }, [api.commentActions, documentData, viewerState.activePage, viewerState.showComments]);
  (0, _react.useEffect)(() => {
    const disposables = [_clientUtils.Trace.method({
      object: api.commentActions,
      isAsync: true,
      methodName: 'addPreviewComment',
      method: api.commentActions.addPreviewComment,
      onFinished: async ({
        returned
      }) => {
        const a = await returned;
        setComments([...comments, a]);
        viewerState.updateState({
          isPlacingCommentMarker: false
        });
      }
    }), _clientUtils.Trace.method({
      object: api.commentActions,
      method: api.commentActions.deletePreviewComment,
      methodName: 'deletePreviewComment',
      isAsync: true,
      onFinished: async ({
        returned,
        methodArguments
      }) => {
        const returnedValue = await returned;

        if (returnedValue.modified) {
          setComments(comments.filter(c => c.id !== methodArguments[0].commentId));
        }
      }
    })];
    return () => disposables.forEach(d => d.dispose());
  }, [api.commentActions, comments, viewerState]);
  return /*#__PURE__*/_react.default.createElement(CommentsContext.Provider, {
    value: { ...api.commentActions,
      comments
    }
  }, props.children);
};

exports.CommentsContextProvider = CommentsContextProvider;
//# sourceMappingURL=comments.js.map