"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DocumentPermissionsContextProvider = exports.DocumentPermissionsContext = void 0;

var _react = _interopRequireWildcard(require("react"));

var _hooks = require("../hooks");

const DocumentPermissionsContext = /*#__PURE__*/(0, _react.createContext)({
  canEdit: false,
  canHideRedaction: false,
  canHideWatermark: false
});
exports.DocumentPermissionsContext = DocumentPermissionsContext;

const DocumentPermissionsContextProvider = ({
  children
}) => {
  const {
    documentData
  } = (0, _hooks.useDocumentData)();
  const api = (0, _hooks.useDocumentViewerApi)();
  const [canEdit, setcanEdit] = (0, _react.useState)(false);
  const [canHideRedaction, setcanHideRedaction] = (0, _react.useState)(false);
  const [canHideWatermark, setcanHideWatermark] = (0, _react.useState)(false);
  const documentIdOrPath = documentData.idOrPath;
  (0, _react.useEffect)(() => {
    const abortController = new AbortController();

    (async () => {
      try {
        const canEditPromise = api.canEditDocument({
          idOrPath: documentIdOrPath,
          abortController
        });
        const cancanHideRedactionPromise = api.canHideRedaction({
          idOrPath: documentIdOrPath,
          abortController
        });
        const canHideWatermarkPromise = api.canHideWatermark({
          idOrPath: documentIdOrPath,
          abortController
        });
        const [canEditValue, canHideRedactionValue, canHideWatermarkValue] = await Promise.all([canEditPromise, cancanHideRedactionPromise, canHideWatermarkPromise]);
        setcanEdit(canEditValue);
        setcanHideRedaction(canHideRedactionValue);
        setcanHideWatermark(canHideWatermarkValue);
      } catch (error) {
        if (!abortController.signal.aborted) {
          throw error;
        }
      }
    })();
  }, [api, documentIdOrPath]);
  return /*#__PURE__*/_react.default.createElement(DocumentPermissionsContext.Provider, {
    value: {
      canEdit,
      canHideRedaction,
      canHideWatermark
    }
  }, children);
};

exports.DocumentPermissionsContextProvider = DocumentPermissionsContextProvider;
//# sourceMappingURL=document-permissions.js.map