"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PreviewImageDataContextProvider = exports.PreviewImageDataContext = void 0;

var _react = _interopRequireWildcard(require("react"));

var _enums = require("../enums");

var _hooks = require("../hooks");

const PreviewImageDataContext = /*#__PURE__*/(0, _react.createContext)({
  imageData: [],
  setImageData: () => ({})
});
exports.PreviewImageDataContext = PreviewImageDataContext;

const PreviewImageDataContextProvider = props => {
  const viewerSettings = (0, _hooks.useViewerSettings)();
  const api = (0, _hooks.useDocumentViewerApi)();
  const {
    documentData
  } = (0, _hooks.useDocumentData)();
  const viewerState = (0, _hooks.useViewerState)();
  const [previewImages, setPreviewImages] = (0, _react.useState)([]);
  (0, _react.useEffect)(() => {
    if (documentData.pageCount <= _enums.PreviewState.Empty) {
      return;
    }

    const abortController = new AbortController();

    (async () => {
      try {
        setPreviewImages([]);
        const images = await api.getExistingPreviewImages({
          document: documentData,
          version: viewerSettings.version || '',
          showWatermark: viewerState.showWatermark,
          abortController
        });
        setPreviewImages(images);
      } catch (error) {
        if (!abortController.signal.aborted) {
          throw error;
        }
      }
    })();

    return () => abortController.abort();
  }, [api, documentData, viewerSettings.version, viewerState.showWatermark]);
  return /*#__PURE__*/_react.default.createElement(PreviewImageDataContext.Provider, {
    value: {
      imageData: previewImages,
      setImageData: setPreviewImages
    }
  }, props.children);
};

exports.PreviewImageDataContextProvider = PreviewImageDataContextProvider;
//# sourceMappingURL=preview-image-data.js.map