import { Button, ClickAwayListener, createStyles, makeStyles, Popper } from '@material-ui/core';
import yellow from '@material-ui/core/colors/yellow.js';
import { Delete } from '@material-ui/icons';
import React, { useState } from 'react';
import { useLocalization } from "../../index.js";
import { useDocumentPermissions } from "../../hooks/index.js";
const useStyles = makeStyles(theme => createStyles({
  root: {
    top: ({
      dimensions
    }) => dimensions.top,
    left: ({
      dimensions
    }) => dimensions.left,
    width: ({
      dimensions
    }) => dimensions.width,
    height: ({
      dimensions
    }) => dimensions.height,
    position: 'absolute',
    resize: ({
      permissions,
      rotationDegree
    }) => permissions.canEdit && rotationDegree === 0 ? 'both' : 'none',
    overflow: 'auto',
    backgroundColor: yellow[600],
    opacity: 0.5
  },
  button: {
    backgroundColor: theme.palette.error.light
  }
}));
/**
 * Return a styled highlight component
 * @param shape Shape attributes
 * @param permissions Permissions of the current user
 * @param dimensions Shape dimensions
 * @param zoomRatio Zoom ratio
 * @param onDragStart Function triggered on drag event
 * @param onResized Function triggered on resized event
 * @param removeShape Function triggered on delete
 * @returns styled highlight component
 */

export const ShapeHighlight = props => {
  const permissions = useDocumentPermissions();
  const classes = useStyles({ ...props,
    permissions
  });
  const localization = useLocalization();
  const [anchorEl, setAnchorEl] = useState(null);
  const open = Boolean(anchorEl);
  const id = open ? 'highlight-delete' : undefined;

  const onRightClick = event => {
    event.preventDefault();
    setAnchorEl(anchorEl ? null : event.currentTarget);
  };

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    className: classes.root,
    tabIndex: 0,
    draggable: permissions.canEdit,
    onDragStart: props.onDragStart,
    onMouseUp: props.onResized,
    onContextMenu: onRightClick
  }), /*#__PURE__*/React.createElement(Popper, {
    id: id,
    open: open,
    anchorEl: anchorEl,
    placement: "right-start"
  }, /*#__PURE__*/React.createElement(ClickAwayListener, {
    onClickAway: () => setAnchorEl(null)
  }, /*#__PURE__*/React.createElement(Button, {
    variant: "contained",
    className: classes.button,
    onMouseUp: () => props.removeShape('highlights', props.shape.guid),
    startIcon: /*#__PURE__*/React.createElement(Delete, {
      scale: props.zoomRatio
    })
  }, localization.delete))));
};
//# sourceMappingURL=shape-highlight.js.map